@@ -1,6 +1,6 @@
 /*
  * xdx - GTK+ DX-cluster client for amateur radio
- * Copyright (C) 2002-2003 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2002-2006 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,35 +24,11 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <time.h>
+#include <string.h>
+#include <stdlib.h>
 #include "save.h"
 #include "gui.h"
-
-
-static gchar *getdate (void)
-{
-  time_t current;
-  struct tm *timestruct = NULL;
-  gchar datenow[20];
- 
-  time (&current);
-  timestruct = localtime (&current);
-  strftime (datenow, 20, "%Y-%m-%d", timestruct);
-  return (g_strdup(datenow));
-}
-
-
-static gchar *gettime (void)
-{
-  time_t current;
-  struct tm *timestruct = NULL;
-  gchar stimenow[20];
-
-  time (&current);
-  timestruct = localtime (&current);
-  strftime (stimenow, 20, "%T", timestruct);
-  return (g_strdup (stimenow));
-}
-
+#include "utils.h"
 
 void savedx (gchar *dx)
 {
@@ -63,8 +39,8 @@ void savedx (gchar *dx)
   fp = fopen (savedxfile, "a");
   if (fp)
   {
-    d = getdate ();
-    t = gettime ();
+    d = getdate (TRUE);
+    t = gettime (TRUE);
     fprintf (fp, "%s %s GMT - %s", d, t, dx);
     g_free (t);
     g_free (d);
@@ -73,22 +49,79 @@ void savedx (gchar *dx)
   g_free (savedxfile);
 }
 
+/* in lines that look like this:
+  "SFI=75, A=2, K=2, R= 13" 
+  "K=0 expK=0 A=4 R=13 SFI=75"
+  extract info after the '=' and save it
+*/
+static void appendwwvinfo (FILE *fpointer, gchar *item, gchar *line)
+{
+  gchar *copy = g_strdup (line);
+  gchar *j, *tmp = NULL;
+  gint i = 0;
+
+  copy = my_strreplace (copy, "= ", "=");
+  tmp = strstr (copy, item);
+  if (tmp)
+  {
+    for (j = tmp; ; ++j)
+    {
+      i++;
+      if (*j == ',')
+      {
+        *j = '\0';
+        break;
+      }
+      else 
+      if (*j == ' ')
+      {
+        *j = '\0';
+        break;
+      }
+    }
+    /* use atoi to nuke spaces */
+    fprintf (fpointer, "\t%s", tmp + strlen(item));
+  }
+}
+
 void savewwv (gchar *wwv)
 {
-  gchar *wwvfile, *d, *t;
+  gchar *wwvfile, *d, *t, *tmp, *ind;
   FILE *fp;
 
   wwvfile = g_strdup_printf ("%s/wwv", gui->preferencesdir);
   fp = fopen (wwvfile, "a");
   if (fp)
   {
-    d = getdate ();
-    t = gettime ();
+    d = getdate (TRUE);
+    t = gettime (TRUE);
     fprintf (fp, "%s %s GMT - %s", d, t, wwv);
     g_free (t);
     g_free (d);
     fclose (fp);
   }
+  /* extract wwv hostname and save to seperate file for every host */
+  tmp = g_strdup (wwv + 7);
+  ind = index (tmp, ' ');
+  *ind = '\0';
+  wwvfile = g_strdup_printf ("%s/%s.tsv", gui->preferencesdir, tmp);
+  g_free (tmp);
+  fp = fopen (wwvfile, "a");
+  if (fp)
+  {
+   /* non-formatted use for saving tsv wwv info */
+    d = getdate (FALSE);
+    t = gettime (FALSE);
+    fprintf (fp, "%s%s", d, t);
+    g_free (t);
+    g_free (d);
+    appendwwvinfo (fp, "SFI=", wwv);
+    appendwwvinfo (fp, "A=", wwv);
+    appendwwvinfo (fp, "K=", wwv);
+    appendwwvinfo (fp, "R=", wwv);
+    fprintf (fp, "\n");
+    fclose (fp);
+  }
   g_free (wwvfile);
 }
 
@@ -101,8 +134,8 @@ void savetoall (gchar *toall)
   fp = fopen (toallfile, "a");
   if (fp)
   {
-    d = getdate ();
-    t = gettime ();
+    d = getdate (TRUE);
+    t = gettime (TRUE);
     fprintf (fp, "%s %s GMT - %s", d, t, toall);
     g_free (t);
     g_free (d);
@@ -120,8 +153,8 @@ void savewx (gchar *wx)
   fp = fopen (wxfile, "a");
   if (fp)
   {
-    d = getdate ();
-    t = gettime ();
+    d = getdate (TRUE);
+    t = gettime (TRUE);
     fprintf (fp, "%s %s GMT - %s", d, t, wx);
     g_free (t);
     g_free (d);
